==> deepeval-0.19.0-py3-none-any.whl: deepeval/test_case.py <==
"""Investigate test case.
"""
import hashlib
from dataclasses import dataclass
from typing import Any, List, Optional, Union


@dataclass
class TestCase:
    id: Optional[str] = None

    def __post_init__(self):
        if self.id is None:
            id_string = "".join(str(value) for value in self.__dict__.values())
            self.id = hashlib.md5(id_string.encode()).hexdigest()


@dataclass
class LLMTestCase(TestCase):
    query: str = "-"
    expected_output: str = "-"
    context: Optional[Union[str, List[str]]] = None
    output: str = "-"

    def __post_init__(self):
        super().__post_init__()
        self.__name__ = f"LLMTestCase_{self.id}"

    # def dict(self):
    #     data = {
    #         "metrics": self.metrics,
    #         "id": self.id,
    #     }
    #     if self.query:
    #         data["query"] = self.query
    #     if self.expected_output:
    #         data["expected_output"] = self.expected_output
    #     if self.context:
    #         data["context"] = self.context
    #     if self.output:
    #         data["output"] = self.output
    #     return data


@dataclass
class SearchTestCase(TestCase):
    def __init__(
        self,
        output_list: List[Any],
        golden_list: List[Any],
        query: Optional[str] = None,
        id: Optional[str] = None,
    ):
        super().__init__(id)
        self.output_list = output_list
        self.golden_list = golden_list
        self.query = query


class AgentTestCase(TestCase):
    """Test Case For Agents"""

    pass

==> deepeval-0.20.10-py3-none-any.whl: deepeval/test_case.py <==
"""Investigate test case.
"""
import hashlib
from dataclasses import dataclass
from typing import Any, List, Optional, Union


@dataclass
class TestCase:
    id: Optional[str] = None

    def __post_init__(self):
        if self.id is None:
            id_string = "".join(str(value) for value in self.__dict__.values())
            self.id = hashlib.md5(id_string.encode()).hexdigest()


@dataclass
class LLMTestCase(TestCase):
    def __init__(
        self,
        input: str,
        actual_output: str,
        expected_output: str = "-",
        context: Optional[Union[str, List[str]]] = None,
        id: Optional[str] = None,
    ):
        super().__init__(id)
        self.input = input
        self.actual_output = actual_output
        self.expected_output = expected_output
        # Force context to be a list
        if isinstance(context, str):
            context = [context]
        self.context = context

    def __post_init__(self):
        super().__post_init__()
        self.__name__ = f"LLMTestCase_{self.id}"


@dataclass
class SearchTestCase(TestCase):
    def __init__(
        self,
        output_list: List[Any],
        golden_list: List[Any],
        input: Optional[str] = None,
        id: Optional[str] = None,
    ):
        super().__init__(id)
        self.output_list = output_list
        self.golden_list = golden_list
        self.input = input


class AgentTestCase(TestCase):
    """Test Case For Agents"""

    pass


@dataclass
class ImageTestCase(TestCase):
    """Test Case For Images. This is a beta interface and is subject to change."""

    def __init__(
        self,
        image_path: str,
        query: Optional[str] = None,
        ground_truth_image_path: Optional[str] = None,
        id: Optional[str] = None,
    ):
        self.query = query
        self.image_path = image_path
        self.ground_truth_image_path = ground_truth_image_path
        super().__init__(id)
